==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w menedżerze plików</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Wyczyść log</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Czy na pewno chcesz wyczyścić dziennik?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dni</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 tydzień</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 miesiąc</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 miesiące</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Eksport</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksport</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Zapasowy</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKST (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Eksportowanie...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksport powiódł się</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Błąd eksportu</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksportuj plik</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Okres:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Lista aplikacji:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Typ wydarzenia:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Akcja:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa Użytkownika:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Rekord rozruchowy</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Zamknij rekord</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Rekord logowania</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Zapasowy</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alarm</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Plik dziennika jest pusty</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Przeglądarka dziennika</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Przeglądarka dzienników to przydatne narzędzie do przeglądania dzienników systemowych.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akcja</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Typ wydarzenia</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data i godzina:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informacje:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Zero</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Dziennik systemu</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Dziennik jądra</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Dziennik rozruchu</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Dziennik Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Dziennik Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Dziennik aplikacji</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Zdarzenie zamknięcia systemu</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Częstotliwość odświeżania</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sekund</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 minuta</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 minut</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Nie odświeżaj</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksportuj wszystko</translation>
    </message>
    <message>
        <source>System Logs</source>
        <translation>Logi systemowe</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Wyświetl w Menedżerze plików</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Wyczyść dziennik</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Odśwież</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Czy na pewno chcesz wyczyścić dziennik?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Potwierdź</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Dzisiaj</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 dni</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1 tydzień</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 miesiąc</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 miesiące</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportuj</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Wszystko</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Awaria</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Logowanie</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Boot</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation>Uwierzytelnienie tożsamości</translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation>Dowolna kontrola dostępu</translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation>Wymuszona kontrola dostępu</translation>
    </message>
    <message>
        <source>Remote</source>
        <translation>Zdalnie</translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation>Audyt dokumentu</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Inne</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation>zip(*.zip)</translation>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEKST (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Eksportowanie...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Eksport zakończony pomyślnie</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Błąd eksportu</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation>Ścieżka eksportu nie jest dostępna. Wybierz inny katalog, aby wykonać operacje.</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Eksportuj plik</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Okres:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Typ wydarzenia:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Akcja:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Zapis boot</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Wpis zamknięcia systemu</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Wpisy logowania</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation>Typ audytu:</translation>
    </message>
    <message>
        <source>Application:</source>
        <translation>Aplikacja:</translation>
    </message>
    <message>
        <source>Submodule:</source>
        <translation>Podmoduł:</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Ostrzeżenie</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Awaria</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Alert</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Krytyczny</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Ogłoszenie</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Ślad</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Bardzo krytyczny</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Plik dziennika jest pusty</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Przeglądarka dziennika</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Przeglądarka dziennika to przydatne narzędzie do przeglądania dzienników systemowych.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Brak wyników wyszukiwania</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Poziom</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Proces</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Użytkownik</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Akcja</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Typ wydarzenia</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Poziom:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Proces:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Data i godzina:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Informacje:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Użytkownik:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation>Data modyfikacji</translation>
    </message>
    <message>
        <source>SIG</source>
        <translation>SIG</translation>
    </message>
    <message>
        <source>EXE</source>
        <translation>EXE</translation>
    </message>
    <message>
        <source>Core File</source>
        <translation>Plik główny</translation>
    </message>
    <message>
        <source>User Name </source>
        <translation>Nazwa użytkownika </translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>Offset</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Data i godzina</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Dziennik systemu</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Dziennik kernela</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Dziennik rozruchu</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>Dziennik dpkg</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Dziennik Kwin</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Dziennik Xorg</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Dziennik aplikacji</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Zdarzenie zamknięcia systemu</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>Dziennik dnf</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation>Inne dzienniki</translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation>Własne dzienniki</translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation>Dziennik audytu</translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation>Dziennik Coredump</translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation>Nie można uzyskać informacji o usterce, zainstaluj systemd-coredump.</translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation>Nie posiadasz uprawnień, aby to wyświetlić</translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation>Poziom bezpieczeństwa tego systemu: wysoki
 tylko administrator kontrolny może wyświetlić dziennik audytu</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation>Eksportuj dziennik do wybranej ścieżki</translation>
    </message>
    <message>
        <source>PATH</source>
        <translation>ŚCIEŻKA</translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation>Eksportuj dzienniki wybranego typu</translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation>TYP</translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation>Eksportuj dzienniki wybranych własnoręcznie stworzonych aplikacji</translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation>NAZWA APLIKACJI</translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation>Eksportuj dzienniki w określonym przedziale czasu</translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation>OKRES</translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation>Eksportuj dzienniki na określonym poziomie debug</translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation>POZIOM</translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation>STATUS BOOT</translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation>Eksportuj dzienniki boot(no-klu) z określonym statusem</translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation>Eksportuj zdarzenia zamknięcia systemu lub dzienniki audytu z określonym typem wydarzenia</translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation>TYP WYDARZENIA</translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation>Eksportuj dzienniki na podstawie wyszukiwania słów kluczowych</translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation>SŁOWO KLUCZOWE</translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation>Zgłoś informacje coredump.</translation>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation>Eksportuj dzienniki z określonym podmodułem aplikacji</translation>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation>PODMODUŁ</translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation>Częstotliwość odświeżania</translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation>10 sek</translation>
    </message>
    <message>
        <source>1 min</source>
        <translation>1 min</translation>
    </message>
    <message>
        <source>5 min</source>
        <translation>5 min</translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation>Nie odświeżaj</translation>
    </message>
    <message>
        <source>Export All</source>
        <translation>Eksportuj wszystko</translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation>Odśwież teraz</translation>
    </message>
</context>
</TS>
